@@ -1,5 +1,5 @@
 from traject._traject import parse, subpatterns, Patterns
-from traject._traject import (register, register_inverse,
+from traject._traject import (register_converter, register, register_inverse,
                               resolve, resolve_stack,
                               consume, consume_stack,
                               locate)
